@@ -1,12 +1,12 @@
-
-# project
+"""Python linter to check TODO comments for consistency and best practice.
+"""
 from ._checker import Checker
 from ._error import Error
 from ._rules import register_rule, rules
 from ._token import Token
 
 
-__version__ = '0.1.5'
+__version__ = '0.2.0'
 
 # keep sorted
 __all__ = [
